<?php

/**
 * @file
 * API documentation for hooks invoked (provided) by the Project issue module.
 */

/**
 * Alter hook for the internal links at the top of issue node pages.
 *
 * @param array $links
 *   Reference to an array of all the "Jump to" links to render at the top of
 *   issue node pages. By default, these are the links for "Most recent
 *   comment", "Add new comment", etc.
 * @param stdClass $node
 *   The fully-loaded project_issue node the links belong to.
 *
 * @see project_issue_internal_links()
 * @see drupal_alter()
 */
function hook_project_issue_internal_links_alter(&$links, $node) {
  $links[] = l(t('Most excellent comment'), "node/$node->nid", array('fragment' => 'excellent')); // If only it were so easy. ;)
}

/**
 * Alter project issue JSON data before it is returned.
 *
 * @param array $issue
 *   An associative array containing information about the project issue node
 *   for which JSON is returned. Passed by reference.
 * @param array $context
 *   An associative array containing contextual information:
 *   - issue: The project_issue node.
 *   - project: The project node associated with the issue.
 *   - release: (optional) The project_release node associated with the issue.
 *   - assigned: (optional) The user account being assigned to the issue.
 *   - author: (optional) The author of the project_issue node.
 *   Optional contexts may contain NULL values for basic entity properties if
 *   no associated data could be loaded.
 *
 * Modules should not change the 'api-version' unless required, as this implies
 * an API change for consumers, and Project Issue module may change the API
 * version on its own.
 *
 * @see project_issue_json()
 * @see drupal_alter()
 */
function hook_project_issue_json_alter(&$issue, $context) {
  $result = comment_upload_fetch_all($issue['id'], FALSE);
  while ($row = db_fetch_object($result)) {
    $issue['attachments'][$row->cid]['contributorId'] = $row->uid;
    $issue['attachments'][$row->cid]['commentId'] = $row->cid;
    $issue['attachments'][$row->cid]['urls'][$row->fid] = file_create_url($row->filepath);
  }
}
